==> recup_app_storybook-1.6.0.tar.gz: lib/stories/cards/card_category/card_category.dart <==
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:recup_app_storybook/stories/data_display/avatar/avatar.dart';

class RecupCategoryCard extends GetView {
  final void Function()? onTap;
  final String backgroundImage;
  final Color? color;
  final String iconImage;
  final String text;
  const RecupCategoryCard({
    this.iconImage = '',
    this.text = '',
    this.color,
    this.backgroundImage = '',
    this.onTap,
    Key? key,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      onTap: onTap,
      child: Container(
        width: 150,
        height: 200,
        padding: const EdgeInsets.only(left: 10, right: 10, top: 10),
        decoration: BoxDecoration(
          color: color,
          borderRadius: BorderRadius.circular(10),
        ),
        child: Stack(
          children: [
            Positioned(
              bottom: -40,
              child: Container(
                width: 130,
                height: 130,
                decoration: BoxDecoration(
                  image: DecorationImage(
                    image: NetworkImage(backgroundImage),
                    fit: BoxFit.cover,
                  ),
                  borderRadius: BorderRadius.circular(10),
                ),
              ),
            ),
            Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              mainAxisAlignment: MainAxisAlignment.start,
              children: [
                SizedBox(
                  child: RecupAvatar(
                    foto: iconImage,
                    backgroundColor: Colors.transparent,
                  ),
                ),
                SizedBox(
                  width: 140,
                  child: Text(
                    text,
                    textAlign: TextAlign.start,
                    overflow: TextOverflow.ellipsis,
                    maxLines: 2,
                    style: Theme.of(context).textTheme.titleMedium?.copyWith(
                          color: Colors.white,
                        ),
                  ),
                ),
              ],
            ),
          ],
        ),
      ),
    );
  }
}

==> recup_app_storybook-1.7.0.tar.gz: lib/stories/cards/card_category/card_category.dart <==
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:recup_app_storybook/stories/data_display/avatar/avatar.dart';

class RecupCategoryCard extends GetView {
  final void Function()? onTap;
  final String backgroundImage;
  final Color? color;
  final String iconImage;
  final String text;
  const RecupCategoryCard({
    this.iconImage = '',
    this.text = '',
    this.color,
    this.backgroundImage = '',
    this.onTap,
    Key? key,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      onTap: onTap,
      child: Container(
        width: 150,
        height: 200,
        padding: const EdgeInsets.only(left: 10, right: 10, top: 10),
        decoration: BoxDecoration(
          color: color,
          borderRadius: BorderRadius.circular(10),
        ),
        child: Stack(
          children: [
            Positioned(
              bottom: -40,
              child: Container(
                width: 130,
                height: 130,
                decoration: BoxDecoration(
                  image: DecorationImage(
                    image: NetworkImage(backgroundImage),
                    fit: BoxFit.cover,
                  ),
                  borderRadius: BorderRadius.circular(10),
                ),
              ),
            ),
            Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              mainAxisAlignment: MainAxisAlignment.start,
              children: [
                SizedBox(
                  child: RecupAvatar(
                    foto: iconImage,
                    backgroundColor: Colors.transparent,
                  ),
                ),
                SizedBox(
                  width: 140,
                  child: Text(
                    text,
                    textAlign: TextAlign.start,
                    overflow: TextOverflow.ellipsis,
                    maxLines: 2,
                    style: Theme.of(context).textTheme.labelMedium?.copyWith(
                          color: Colors.white,
                        ),
                  ),
                ),
              ],
            ),
          ],
        ),
      ),
    );
  }
}
